@@ -27,11 +27,11 @@
 #' unlink(c("Makefile", "report.Rmd"))
 #' }
 #' @references \url{https://github.com/wlandau-lilly/drake}
-#' @importFrom base64url base32_encode
 #' @importFrom codetools findGlobals
 #' @importFrom crayon make_style
 #' @importFrom digest digest
 #' @importFrom eply quotes strings unquote
+#' @importFrom grDevices col2rgb rgb
 #' @importFrom igraph adjacent_vertices delete_vertices edge
 #' is_dag make_empty_graph plot.igraph subcomponent V vertex
 #' @importFrom lubridate dseconds duration
@@ -40,14 +40,25 @@
 #' mclapply parLapply stopCluster
 #' @importFrom plyr ddply dlply
 #' @importFrom R.utils isPackageLoaded
+#' @importFrom rprojroot find_root
 #' @importFrom stats coef complete.cases lm rnorm rpois runif setNames
 #' @importFrom storr encode64 storr_rds
 #' @importFrom stringi stri_extract_all_regex stri_rand_strings
 #' @importFrom stringr str_split str_trim
-#' @importFrom testthat expect_false expect_true test_that
-#' @importFrom tools md5sum
-#' @importFrom utils capture.output sessionInfo unzip
+#' @importFrom testthat expect_false expect_true test_dir test_that
+#' @importFrom utils capture.output compareVersion sessionInfo unzip
 #' @importFrom visNetwork toVisNetworkData visEvents visHierarchicalLayout
 #' visIgraphLayout visInteraction visLegend visNetwork visSave
-#' @importFrom withr with_dir
+#' @importFrom withr with_dir with_options with_output_sink
 NULL
+
+#' @title Pipe operator
+#' @export
+#' @description Pipe operator from the \code{magrittr} package
+#' @param lhs left-hand side argument
+#' @param rhs right-hand side argument
+#' @examples
+#' rnorm(2) %>%
+#'   mean %>%
+#'   c("third element")
+`%>%` <- magrittr::`%>%`
