@@ -1,12 +1,11 @@
+cat(get_testing_scenario_name(), ": ", sep = "")
 context("basic")
 
 test_with_dir("basic example works", {
-  dclean()
-  opt <- test_opt()
-  e <- eval(parse(text = opt$envir))
-  jobs <- opt$jobs
-  parallelism <- opt$parallelism
-  dclean()
+  scenario <- get_testing_scenario()
+  e <- eval(parse(text = scenario$envir))
+  jobs <- scenario$jobs
+  parallelism <- scenario$parallelism
 
   load_basic_example(envir = e)
   my_plan <- e$my_plan
@@ -53,7 +52,17 @@ test_with_dir("basic example works", {
   expect_equal(max_useful_jobs(my_plan, envir = e, imports = "none",
     config = config), 8)
 
+  dats <- c("small", "large")
+  config$targets <- dats
   con <- testrun(config)
+  expect_equal(sort(justbuilt(con)), sort(dats))
+  remove_these <- intersect(dats, ls(config$envir))
+  rm(list = remove_these, envir = config$envir)
+  config$targets <- config$plan$target
+  con <- testrun(config)
+  jb <- justbuilt(con)
+  expect_true("'report.md'" %in% jb)
+  expect_false(any(dats %in% jb))
 
   # Check that file is not rehashed.
   # Code coverage should cover every line of file_hash().
@@ -88,6 +97,8 @@ test_with_dir("basic example works", {
     "summ_regression2_small")))
   expect_equal(max_useful_jobs(my_plan, envir = e, config = config),
     4)
+  expect_equal(max_useful_jobs(my_plan, envir = e, config = config,
+    from_scratch = TRUE), 8)
   expect_equal(max_useful_jobs(my_plan, envir = e, imports = "files",
     config = config), 4)
   expect_true(max_useful_jobs(my_plan, envir = e, imports = "all",
@@ -105,5 +116,4 @@ test_with_dir("basic example works", {
   tmp <- dataframes_graph(my_plan, envir = e, jobs = jobs,
     parallelism = parallelism, verbose = FALSE)
   expect_true(is.data.frame(tmp$nodes))
-  dclean()
 })
