@@ -1,7 +1,7 @@
+cat(get_testing_scenario_name(), ": ", sep = "")
 context("examples")
 
 test_with_dir("examples are listed and written", {
-  dclean()
   x <- examples_drake()
   expect_true(is.character(x) & length(x) > 0)
   for (i in x){
@@ -11,5 +11,4 @@ test_with_dir("examples are listed and written", {
     expect_true(file.info(i)$isdir)
     unlink(i, recursive = TRUE, force = TRUE)
   }
-  dclean()
 })
